/****************************************************************************
** Meta object code from reading C++ file 'activityinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.6.5/libtaskmanager/activityinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'activityinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TaskManager12ActivityInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto TaskManager::ActivityInfo::qt_create_metaobjectdata<qt_meta_tag_ZN11TaskManager12ActivityInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TaskManager::ActivityInfo",
        "QML.Element",
        "auto",
        "currentActivityChanged",
        "",
        "numberOfRunningActivitiesChanged",
        "namesOfRunningActivitiesChanged",
        "runningActivities",
        "activityName",
        "id",
        "activityIcon",
        "currentActivity",
        "numberOfRunningActivities"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentActivityChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'numberOfRunningActivitiesChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'namesOfRunningActivitiesChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'runningActivities'
        QtMocHelpers::MethodData<QStringList() const>(7, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'activityName'
        QtMocHelpers::MethodData<QString(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'activityIcon'
        QtMocHelpers::MethodData<QString(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentActivity'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'numberOfRunningActivities'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ActivityInfo, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TaskManager::ActivityInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager12ActivityInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager12ActivityInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TaskManager12ActivityInfoE_t>.metaTypes,
    nullptr
} };

void TaskManager::ActivityInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActivityInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentActivityChanged(); break;
        case 1: _t->numberOfRunningActivitiesChanged(); break;
        case 2: _t->namesOfRunningActivitiesChanged(); break;
        case 3: { QStringList _r = _t->runningActivities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->activityName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->activityIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActivityInfo::*)() const>(_a, &ActivityInfo::currentActivityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivityInfo::*)() const>(_a, &ActivityInfo::numberOfRunningActivitiesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivityInfo::*)() const>(_a, &ActivityInfo::namesOfRunningActivitiesChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->currentActivity(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->numberOfRunningActivities(); break;
        default: break;
        }
    }
}

const QMetaObject *TaskManager::ActivityInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TaskManager::ActivityInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager12ActivityInfoE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TaskManager::ActivityInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void TaskManager::ActivityInfo::currentActivityChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::ActivityInfo *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TaskManager::ActivityInfo::numberOfRunningActivitiesChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::ActivityInfo *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TaskManager::ActivityInfo::namesOfRunningActivitiesChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::ActivityInfo *>(this), &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
